==> snipe-it-7.0.11.zip: snipe-it-7.0.11/resources/lang/fi-FI/admin/hardware/form.php <==
<?php

return [
    'bulk_delete'		=> 'Vahvista laitteiden massapoisto',
    'bulk_restore'      => 'Vahvista laitteiden massapalautus', 
  'bulk_delete_help'	=> 'Tarkasta alla olevat massapoistettavat laitteet. Kun nämä laitteet on poistettu, ne voidaan palauttaa, mutta niitä ei enää yhdistetä niihin käyttäjiin, joille ne on tällä hetkellä luovutettuna.',
  'bulk_restore_help'	=> 'Tarkista massapalautettavat laitteet alla. Kun nämä laitteet on palautettu, niitä ei liitetä mihinkään käyttäjiin, joille ne on aiemmin osoitettu.',
  'bulk_delete_warn'	=> 'Olet poistamassa :asset_count laitetta.',
  'bulk_restore_warn'	=> 'Olet palauttamassa :asset_count laitetta.',
    'bulk_update'		=> 'Massapäivitä laitteita',
    'bulk_update_help'	=> 'Tämän lomakkeen avulla voit päivittää useita laitteita kerralla. Täytä vain ne kentät joita haluat muuttaa. Tyhjäksi jätettyjä kenttiä ei päivitetä. ',
    'bulk_update_warn'	=> 'Olet muokkaamassa yhden laitteen ominaisuuksia.- Olet muokkaamassa :asset_count laitteen ominaisuuksia.',
    'bulk_update_with_custom_field' => 'Huomaa, että assetit ovat :asset_model_count erilaisia malleja.',
    'bulk_update_model_prefix' => 'Malleissa', 
    'bulk_update_custom_field_unique' => 'Tämä on ainutlaatuinen kenttä eikä sitä voi muokata.',
    'checkedout_to'		=> 'Luovutettuna',
    'checkout_date'		=> 'Luovutuspäivä',
    'checkin_date'		=> 'Palautuspäivä',
    'checkout_to'		=> 'Luovutettu',
    'cost'				=> 'Hankintahinta',
    'create'			=> 'Uusi laite',
    'date'				=> 'Hankintapäivämäärä',
    'depreciation'	    => 'Poisto',
    'depreciates_on'	=> 'Poistoaika',
    'default_location'	=> 'Oletussijainti',
    'default_location_phone' => 'Oletus Sijainti Puhelin',
    'eol_date'			=> 'Poistopäivä',
    'eol_rate'			=> 'Poistonopeus',
    'expected_checkin'  => 'Odotettu palautuspäivä',
    'expires'			=> 'Vanhenee',
    'fully_depreciated'	=> 'Kokonaan Poistettu',
    'help_checkout'		=> 'Jos haluat määrittää tämän laitteen välittömästi, valitse valintaluettelosta "Valmis käyttöönottoon". ',
    'mac_address'		=> 'MAC-osoite',
    'manufacturer'		=> 'Valmistaja',
    'model'				=> 'Malli',
    'months'			=> 'kuukautta',
    'name'				=> 'Laitteen nimi',
    'notes'				=> 'Muistiinpanot',
    'order'				=> 'Tilausnumero',
    'qr'				=> 'QR-koodi',
    'requestable'		=> 'Käyttäjät voivat pyytää tätä laitetta',
    'redirect_to_all'   => 'Return to all :type',
    'redirect_to_type'   => 'Go to :type',
    'redirect_to_checked_out_to'   => 'Go to Checked Out to',
    'select_statustype'	=> 'Valitse tila',
    'serial'			=> 'Sarjanumero',
    'status'			=> 'Tila',
    'tag'				=> 'Laitetunniste',
    'update'			=> 'Päivitä laite',
    'warranty'			=> 'Takuu',
        'warranty_expires'		=> 'Takuu päättyy',
    'years'				=> 'vuotta',
    'asset_location' => 'Päivitä sijainti',
    'asset_location_update_default_current' => 'Päivitä oletussijainti ja todellinen sijainti',
    'asset_location_update_default' => 'Päivitä vain oletussijainti',
    'asset_location_update_actual' => 'Päivitä vain todellinen sijainti',
    'asset_not_deployable' => 'Laite ei ole käyttöönotettavissa. Laitetta ei voida luovuttaa.',
    'asset_deployable' => 'Laite on käyttöönotettavissa. Laite voidaan luovuttaa.',
    'processing_spinner' => 'Käsitellään... (Tämä saattaa kestää jonkin aikaa suurien tiedostojen kanssa)',
    'optional_infos'  => 'Valinnaiset tiedot',
    'order_details'   => 'Tilaukseen liityvät tiedot'
];

==> snipe-it-7.0.13.zip: snipe-it-7.0.13/resources/lang/fi-FI/admin/hardware/form.php <==
<?php

return [
    'bulk_delete'		=> 'Vahvista laitteiden massapoisto',
    'bulk_restore'      => 'Vahvista laitteiden massapalautus', 
  'bulk_delete_help'	=> 'Tarkasta alla olevat massapoistettavat laitteet. Kun nämä laitteet on poistettu, ne voidaan palauttaa, mutta niitä ei enää yhdistetä niihin käyttäjiin, joille ne on tällä hetkellä luovutettuna.',
  'bulk_restore_help'	=> 'Tarkista massapalautettavat laitteet alla. Kun nämä laitteet on palautettu, niitä ei liitetä mihinkään käyttäjiin, joille ne on aiemmin osoitettu.',
  'bulk_delete_warn'	=> 'Olet poistamassa :asset_count laitetta.',
  'bulk_restore_warn'	=> 'Olet palauttamassa :asset_count laitetta.',
    'bulk_update'		=> 'Massapäivitä laitteita',
    'bulk_update_help'	=> 'Tämän lomakkeen avulla voit päivittää useita laitteita kerralla. Täytä vain ne kentät joita haluat muuttaa. Tyhjäksi jätettyjä kenttiä ei päivitetä. ',
    'bulk_update_warn'	=> 'Olet muokkaamassa yhden laitteen ominaisuuksia.- Olet muokkaamassa :asset_count laitteen ominaisuuksia.',
    'bulk_update_with_custom_field' => 'Huomaa, että assetit ovat :asset_model_count erilaisia malleja.',
    'bulk_update_model_prefix' => 'Malleissa', 
    'bulk_update_custom_field_unique' => 'Tämä on ainutlaatuinen kenttä eikä sitä voi muokata.',
    'checkedout_to'		=> 'Luovutettuna',
    'checkout_date'		=> 'Luovutuspäivä',
    'checkin_date'		=> 'Palautuspäivä',
    'checkout_to'		=> 'Luovutettu',
    'cost'				=> 'Hankintahinta',
    'create'			=> 'Uusi laite',
    'date'				=> 'Hankintapäivämäärä',
    'depreciation'	    => 'Poisto',
    'depreciates_on'	=> 'Poistoaika',
    'default_location'	=> 'Oletussijainti',
    'default_location_phone' => 'Oletus Sijainti Puhelin',
    'eol_date'			=> 'Poistopäivä',
    'eol_rate'			=> 'Poistonopeus',
    'expected_checkin'  => 'Odotettu palautuspäivä',
    'expires'			=> 'Vanhenee',
    'fully_depreciated'	=> 'Kokonaan Poistettu',
    'help_checkout'		=> 'Jos haluat määrittää tämän laitteen välittömästi, valitse valintaluettelosta "Valmis käyttöönottoon". ',
    'mac_address'		=> 'MAC-osoite',
    'manufacturer'		=> 'Valmistaja',
    'model'				=> 'Malli',
    'months'			=> 'kuukautta',
    'name'				=> 'Laitteen nimi',
    'notes'				=> 'Muistiinpanot',
    'order'				=> 'Tilausnumero',
    'qr'				=> 'QR-koodi',
    'requestable'		=> 'Käyttäjät voivat pyytää tätä laitetta',
    'redirect_to_all'   => 'Return to all :type',
    'redirect_to_type'   => 'Go to :type',
    'redirect_to_checked_out_to'   => 'Go to Checked Out to',
    'select_statustype'	=> 'Valitse tila',
    'serial'			=> 'Sarjanumero',
    'status'			=> 'Tila',
    'tag'				=> 'Laitetunniste',
    'update'			=> 'Päivitä laite',
    'warranty'			=> 'Takuu',
        'warranty_expires'		=> 'Takuu päättyy',
    'years'				=> 'vuotta',
    'asset_location' => 'Päivitä sijainti',
    'asset_location_update_default_current' => 'Päivitä oletussijainti ja todellinen sijainti',
    'asset_location_update_default' => 'Päivitä vain oletussijainti',
    'asset_location_update_actual' => 'Päivitä vain todellinen sijainti',
    'asset_not_deployable' => 'Laite ei ole käyttöönotettavissa. Laitetta ei voida luovuttaa.',
    'asset_not_deployable_checkin' => 'That asset status is not deployable. Using this status label will checkin the asset.',
    'asset_deployable' => 'Laite on käyttöönotettavissa. Laite voidaan luovuttaa.',
    'processing_spinner' => 'Käsitellään... (Tämä saattaa kestää jonkin aikaa suurien tiedostojen kanssa)',
    'optional_infos'  => 'Valinnaiset tiedot',
    'order_details'   => 'Tilaukseen liityvät tiedot'
];
